{% extends "admin/change_form.html" %}{% load i18n static admin_list admin_urls %}
{% load changeform_actions %}
{% block object-tools-items %}
    {{ block.super }}

    {% get_changeform_actions_dropdown adminform.model_admin as select_html %}
    {{ select_html|safe }}
{% endblock %}
